from setuptools import setup

setup(name='gaus_binomial_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      author= 'Omariba collins',
      author_email= 'collinsomariba@gmail.com',
      packages=['distributions'],
      zip_safe=False)
 